@@ -470,6 +470,7 @@
            sigmasq = c(lower=0, upper=+Inf),
            nugget.rel = c(lower=0, upper=+Inf),
            kappa = c(lower=0, upper=+Inf),
+           kappa2 = c(lower=0, upper=+Inf),
            lambda = c(lower=-3, upper=3),
            psiR = c(lower=1, upper=+Inf),
            psiA = c(lower=0, upper=2*pi),
@@ -484,6 +485,8 @@
     stop("tausq.rel must be a 2 components vector with lower and upper limits for the parameter tausq.rel") 
   if(length(kappa) != 2)
     stop("kappa must be a 2 components vector with lower and upper limits for the parameter kappa") 
+  if(length(kappa2) != 2)
+    stop("kappa must be a 2 components vector with lower and upper limits for the parameter kappa") 
   if(length(lambda) != 2)
     stop("lambda must be a 2 components vector with lower and upper limits for the parameter lambda")
   if(length(psiR) != 2)
@@ -498,6 +501,8 @@
     stop("parameter tausq.rel: lower limit greater or equal upper limit")
   if(kappa[1] >= kappa[2])
     stop("parameter kappa: lower limit greater or equal upper limit")
+  if(kappa2[1] >= kappa2[2])
+    stop("parameter kappa: lower limit greater or equal upper limit")
   if(lambda[1] >= lambda[2])
     stop("parameter lambda: lower limit greater or equal upper limit")
   if(psiR[1] >= psiR[2])
@@ -508,11 +513,12 @@
   names(sigmasq) <- c("lower", "upper")
   names(tausq.rel) <- c("lower", "upper")
   names(kappa) <- c("lower", "upper")
+  names(kappa2) <- c("lower", "upper")
   names(lambda) <- c("lower", "upper")
   names(psiR) <- c("lower", "upper")
   names(psiA) <- c("lower", "upper")
   return(list(phi = phi, sigmasq = sigmasq,
-              tausq.rel = tausq.rel, kappa = kappa,
+              tausq.rel = tausq.rel, kappa = kappa, kappa2 = kappa2,
               lambda = lambda, psiR = psiR, psiA = psiA))
 }
 
